@@ -10,7 +10,7 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::Config;
-$App::SpreadRevolutionaryDate::Config::VERSION = '0.23';
+$App::SpreadRevolutionaryDate::Config::VERSION = '0.24';
 # ABSTRACT: Companion class of L<App::SpreadRevolutionaryDate>, to handle configuration file and command line arguments, subclass of L<AppConfig>.
 
 use Moose;
@@ -229,13 +229,6 @@ sub new {
     $self->check_target_mandatory_options($target);
   }
 
-  # Add acab option for RevolutionaryDate for backward compatibility
-  $self->revolutionarydate_acab($self->acab)
-    if  $self->msgmaker eq 'RevolutionaryDate'
-        && !$self->revolutionarydate_acab
-        && $self->acab;
-
-
   return $self;
 }
 
@@ -304,12 +297,12 @@ sub get_msgmaker_arguments {
 
   # Add acab option for RevolutionaryDate for backward compatibility
   $msgmaker_args{acab} = $self->acab
-    if  $msgmaker eq 'RevolutionaryDate'
-        && !exists($msgmaker_args{acab})
+    if  $msgmaker eq 'revolutionarydate'
+        && !$msgmaker_args{acab}
         && $self->acab;
 
   # Do not prompt if PromptUser default is set
-  if ($msgmaker eq 'PromptUser') {
+  if ($msgmaker eq 'promptuser') {
     require App::SpreadRevolutionaryDate::MsgMaker::PromptUser;
     if ($msgmaker_args{default} && $msgmaker_args{default} ne App::SpreadRevolutionaryDate::MsgMaker::PromptUser->meta->get_attribute('default')->default) {
       $ENV{PERL_MM_USE_DEFAULT} = 1
@@ -376,7 +369,7 @@ App::SpreadRevolutionaryDate::Config - Companion class of L<App::SpreadRevolutio
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 METHODS
 
